==> foundation-2.2.0.tgz: package/lib/esm/text/Text.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsx, css } from "@emotion/react";
import useTheme from "../useTheme";
import { createContext, useContext } from "react";
import useSs from "../useSs";
import { createStyleObject } from "@capsizecss/core";
import isInlineContext from "./isInlineContext";
import useStyleCss from "./useStyleCss";
import getHtmlAttributes from "../getHtmlAttributes";
import { forwardRef } from "react";
var ssProps = ["bg", "radius"];
var IsInlineProvider = isInlineContext.Provider;
var textContext = createContext({});
var Provider = textContext.Provider;
export var TextProvider = function (_a) {
    var children = _a.children, props = __rest(_a, ["children"]);
    return _jsx(Provider, __assign({ value: props }, { children: children }));
};
export default forwardRef(function (_a, ref) {
    var _b, _c, _d;
    var _e = _a.lineGap, lineGap = _e === void 0 ? 1 : _e, props = __rest(_a, ["lineGap"]);
    var _f = useTheme(), fontSize = _f.fontSize, defaultFont = _f.defaultFont, fonts = _f.fonts;
    var ss = useSs(props);
    var contextProps = useContext(textContext);
    props = __assign(__assign({}, contextProps), props);
    var headingLevel = props.headingLevel;
    var font = fonts[(_b = props.font) !== null && _b !== void 0 ? _b : defaultFont];
    var size = (_c = props.size) !== null && _c !== void 0 ? _c : "md";
    var styleCss = useStyleCss(props);
    if (!props.children)
        return null;
    return (_jsx(IsInlineProvider, __assign({ value: true }, { children: jsx((_d = props.as) !== null && _d !== void 0 ? _d : (headingLevel ? "h".concat(headingLevel) : "p"), __assign(__assign({}, getHtmlAttributes(props)), { ref: ref, css: css(ss, styleCss, __assign({ fontFamily: font.name, textAlign: props.align }, createStyleObject({
                capHeight: fontSize(size).raw,
                lineGap: fontSize(size).raw * lineGap,
                fontMetrics: font.metrics,
            }))) }), props.children) })));
});

==> foundation-2.3.1.tgz: package/lib/esm/text/Text.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsx, css } from "@emotion/react";
import useTheme from "../useTheme";
import { createContext, useContext } from "react";
import useSs from "../useSs";
import { createStyleObject } from "@capsizecss/core";
import isInlineContext from "./isInlineContext";
import useStyleCss from "./useStyleCss";
import getHtmlAttributes from "../getHtmlAttributes";
import { forwardRef } from "react";
var ssProps = ["bg", "radius"];
var IsInlineProvider = isInlineContext.Provider;
var textContext = createContext({});
var Provider = textContext.Provider;
export var TextProvider = function (_a) {
    var children = _a.children, props = __rest(_a, ["children"]);
    return _jsx(Provider, __assign({ value: props }, { children: children }));
};
var Text = function (_a, ref) {
    var _b, _c, _d;
    var _e = _a.lineGap, lineGap = _e === void 0 ? 1 : _e, props = __rest(_a, ["lineGap"]);
    var _f = useTheme(), fontSize = _f.fontSize, defaultFont = _f.defaultFont, fonts = _f.fonts;
    var ss = useSs(props);
    var contextProps = useContext(textContext);
    props = __assign(__assign({}, contextProps), props);
    var headingLevel = props.headingLevel;
    var font = fonts[(_b = props.font) !== null && _b !== void 0 ? _b : defaultFont];
    var size = (_c = props.size) !== null && _c !== void 0 ? _c : "md";
    var styleCss = useStyleCss(props);
    if (!props.children)
        return null;
    return (_jsx(IsInlineProvider, __assign({ value: true }, { children: jsx((_d = props.as) !== null && _d !== void 0 ? _d : (headingLevel ? "h".concat(headingLevel) : "p"), __assign(__assign({}, getHtmlAttributes(props)), { ref: ref, css: css(ss, styleCss, __assign({ fontFamily: font.name, textAlign: props.align }, createStyleObject({
                capHeight: fontSize(size).raw,
                lineGap: fontSize(size).raw * lineGap,
                fontMetrics: font.metrics,
            }))) }), props.children) })));
};
export default forwardRef(Text);
